@@ -70,6 +70,13 @@ def test_aws_session_class_profile(tmpdir, monkeypatch):
     monkeypatch.undo()
 
 
+def test_aws_session_class_endpoint():
+    """Confirm that endpoint_url kwarg works."""
+    pytest.importorskip("boto3")
+    sesh = AWSSession(endpoint_url="example.com")
+    assert sesh.get_credential_options()['AWS_S3_ENDPOINT'] == 'example.com'
+
+
 def test_session_factory_unparsed():
     """Get a DummySession for unparsed paths"""
     sesh = Session.from_path("/vsicurl/lolwut")
@@ -195,4 +202,4 @@ def test_session_factory_swift_kwargs():
     sesh = Session.from_path("/vsiswift/lol/wut", swift_storage_url='foo', swift_auth_token='bar')
     assert isinstance(sesh, DummySession)
 
-    
\ No newline at end of file
+    
